# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 Your Name <email@ubuntu.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import gettext
from gettext import gettext as _
gettext.textdomain('klout')

import logging

from gi.repository import Gio # pylint: disable=E0611
from gi.repository import Gtk # pylint: disable=E0611
from pyklout import Klout
from pyklout import KloutError
 
logger = logging.getLogger('klout')

from klout_lib import Window
from klout.AboutKloutDialog import AboutKloutDialog
from klout.PreferencesKloutDialog import PreferencesKloutDialog

class User(object):
    KloutID = 0
    TwitterID = ""
    Name = ""
    KloutScore = 0
    DayDelta = 0
    WeekDelta = 0
    MonthDelta = 0
    KloutAPI = Klout("cdk665pw6ry8rjsa7j4gfgh7")
    ErrorMessage = "Unable to find user"
    IsLoaded = False
    InfluencersCount = 0
    InfluenceesCount = 0
    Influencers = []
    Influencees = []
    Topics = []
    def __init__(self, tid):
        try:
            self.TwitterID = tid
            self.KloutID = self.KloutAPI.identity(tid, 'twitter')['id']
            score = self.KloutAPI.score(self.KloutID)
            self.KloutScore = int(round(score['score'],0))
            self.HasDelta = False
            if 'scoreDelta' in score:
                self.DayDelta = int(round(score['scoreDelta']['dayChange'],0))
                self.WeekDelta = int(round(score['scoreDelta']['weekChange'],0))
                self.MonthDelta =  int(round(score['scoreDelta']['monthChange'],0))
                self.HasDelta = True
            myInfluences =  self.KloutAPI.influences(self.KloutID)
            self.InfluencersCount = int(myInfluences['myInfluencersCount'])
            self.InfluenceesCount = int(myInfluences['myInfluenceesCount'])
            myInfluencers = myInfluences['myInfluencers']
            for i in myInfluencers:
                self.Influencers.append(Influence(i['entity']))
            myInfluencees = myInfluences['myInfluencees']
            for i in myInfluencees:
                self.Influencees.append(Influence(i['entity']))
            myTopics =  self.KloutAPI.topics(self.KloutID)
            for i in myTopics:
                self.Topics.append(Topic(i))
            self.IsLoaded = True
        except KloutError as kerr:
            self.ErrorMessage = "Unable to find user " + tid
            self.IsLoaded = False


class Topic(object):
    imageUrl = ""
    slug = ""
    displayName = ""
    id = 0
    def __init__(self, myTopic):
        self.imageUrl= myTopic['imageUrl']
        self.slug = myTopic['slug']
        print myTopic['displayName']
        self.displayName= myTopic['displayName']
        self.id= myTopic['id']

class Influence(object):
    id=0
    nick = ""
    kloutId = 0
    dayChange = 0
    monthChange = 0
    weekChange = 0
    score = 0
    hasDelta = False
    def __init__(self, myInfluencer):
        self.id= int(myInfluencer['id'])
        self.nick= myInfluencer['payload']['nick'].encode('ascii')
        self.kloutId = int(myInfluencer['payload']['kloutId'])
        if 'scoreDelta' in myInfluencer['payload']:
            self.dayChange = int(round(myInfluencer['payload']['scoreDelta']['dayChange'],0))
            self.weekChange = int(round(myInfluencer['payload']['scoreDelta']['weekChange'],0))
            self.monthChange =  int(round(myInfluencer['payload']['scoreDelta']['monthChange'],0))
            self.hasDelta = True
        self.score= int(round(myInfluencer['payload']['score']['score'],0))


# See klout_lib.Window.py for more details about how this class works
class KloutWindow(Window):
    __gtype_name__ = "KloutWindow"
    
    def finish_initializing(self, builder): # pylint: disable=E1002
        """Set up the main window"""
        super(KloutWindow, self).finish_initializing(builder)

        self.AboutDialog = AboutKloutDialog
        self.PreferencesDialog = PreferencesKloutDialog

        # Code for other initialization actions should be added here.
        self.api = Klout("cdk665pw6ry8rjsa7j4gfgh7")
        self.searchbutton = self.builder.get_object("searchbutton")
        self.spinner1 = self.builder.get_object("spinner1")
        self.twitterentry = self.builder.get_object("twitterentry")
        self.scoreBox = self.builder.get_object("scoreBox")
        self.influenceeBox = self.builder.get_object("influenceeBox")
        self.influencerBox = self.builder.get_object("influencerBox")
        self.topicsBox = self.builder.get_object("topicsBox")
        self.influenceelabel = self.builder.get_object("influenceelabel")
        self.influencerlabel = self.builder.get_object("influencerlabel")
        self.topicslabel = self.builder.get_object("topicslabel")
        self.influenceeWindow = self.builder.get_object("influenceeWindow")
        self.influencerWindow = self.builder.get_object("influencerWindow")
        self.topicsWindow = self.builder.get_object("topicsWindow")
        self.daydelta = self.builder.get_object("daydelta")
        self.monthdelta = self.builder.get_object("monthdelta")
        self.weekdelta = self.builder.get_object("weekdelta")
        self.daychange = self.builder.get_object("daychange")
        self.monthchange = self.builder.get_object("monthchange")
        self.weekchange = self.builder.get_object("weekchange")
        self.scoreimage = self.builder.get_object("kloutscoreimage")
        self.scorebutton = self.builder.get_object("scorebutton")
        self.influenceebutton = self.builder.get_object("influenceebutton")
        self.influencerbutton = self.builder.get_object("influencerbutton")
        self.influencerWindow = self.builder.get_object("influencerWindow")
        self.influencers = self.builder.get_object("influencers")
        self.influencees = self.builder.get_object("influencees")
        self.topics = self.builder.get_object("topics")
        self.topicsbutton = self.builder.get_object("topicsbutton")
        self.deltas = self.builder.get_object("deltagrid")
        self.messagelabel = self.builder.get_object("messagelabel")
        self.myKloutMenu = self.builder.get_object("myKloutMenu")
        self.newSearch = self.builder.get_object("newSearch")
        self.setpreferences = self.builder.get_object("setpreferences")
        self.viewport2 = self.builder.get_object("viewport2")
        settings = Gio.Settings("net.launchpad.klout")
        tid = settings.get_string("example")
        self.currentUser = None
        self.DefaultUser = User(tid)
        self.populateScreen(self.DefaultUser)
        
    def on_myKloutMenu_activate(self, widget) :
        settings = Gio.Settings("net.launchpad.klout")
        tid = settings.get_string("example")
        self.currentUser = None
        if tid != self.DefaultUser.TwitterID:
            self.DefaultUser = User(tid)
        self.populateScreen(self.DefaultUser)

    def on_setpreferences_activate(self, widget) :
        self.PreferencesDialog.show()
        
    def on_newSearch_activate(self, widget) :
        self.resetScreen("Enter a Twitter Name")
        
    def on_twitterentry_activate(self, widget) :
        self.setState("spinner")
        newUser = User(widget.get_text())
        self.populateScreen(newUser)
        
    def on_searchbutton_clicked(self, widget) :
        self.setState("spinner")
        newUser = User(self.twitterentry.get_text())
        self.populateScreen(newUser)
        self.setState("score")
    
    def on_scorebutton_clicked(self, widget) :
        self.setState("score")
        
    def on_influencerbutton_clicked(self, widget) :
        self.setState("influencer")
     
    def on_influenceebutton_clicked(self, widget) :
        self.setState("influencee")  
          
    def on_topicsbutton_clicked(self, widget) :
        self.setState("topics")
    
            
    def resetScreen(self,message):
        self.currentUser = None
        if message != "" :
            self.messagelabel.set_visible(True)
            self.messagelabel.set_visible(True)
        else : 
            self.messagelabel.set_visible(False)
        self.scoreimage.set_from_file("data/media/klout.png")
        self.twitterentry.set_text("")
        self.messagelabel.set_text(str(message))
        self.deltas.set_visible(False)
      
        
   
    def setState(self,state) :
        if state == "spinner":
            self.scoreBox.set_visible(False)
            self.influenceeBox.set_visible(False)
            self.influencerBox.set_visible(False)
            self.topicsBox.set_visible(False)
            self.spinner1.set_visible(True)
            self.spinner1.start()
        elif state =="influencee":
            self.scoreBox.set_visible(False)
            self.influenceeBox.set_visible(True)
            self.influencerBox.set_visible(False)
            self.topicsBox.set_visible(False)
            self.spinner1.set_visible(False)
            self.spinner1.start()
        elif state =="influencer":
            self.scoreBox.set_visible(False)
            self.influenceeBox.set_visible(False)
            self.influencerBox.set_visible(True)
            self.topicsBox.set_visible(False)
            self.spinner1.set_visible(False)
            self.spinner1.start()
        elif state == "topics":
            self.scoreBox.set_visible(False)
            self.influenceeBox.set_visible(False)
            self.influencerBox.set_visible(False)
            self.topicsBox.set_visible(True)
            self.spinner1.set_visible(False)
            self.spinner1.start()          
        else:
            self.spinner1.set_visible(False)
            self.spinner1.stop()
            self.influenceeBox.set_visible(False)
            self.influencerBox.set_visible(False)
            self.topicsBox.set_visible(False)
            self.scoreBox.set_visible(True)
            self.twitterentry.grab_focus()
            
    def populateScreen(self, user) :
        if user.IsLoaded:
            self.currentUser = user
            self.messagelabel.set_visible(False)
            self.twitterentry.set_text(user.TwitterID)
            self.scoreimage.set_from_file("data/media/alert" + str(user.KloutScore) + ".png")
            markup = ""
            for i in user.Influencers:
                markup = markup + "<span size='18000'>"+i.nick+"</span><span size='18000' font_weight='bold' foreground='#e44905'> : "+str(round(i.score,0))+"</span>\n\n"
            if markup ==  "":
                markup =  "<span size='18000'>"+user.TwitterID+" isn't influenced by anyone, yet.</span>"
            self.influencers.set_markup(markup)
            self.influencerlabel.set_text(user.TwitterID+" is influenced by these people")
            markup = ""
            for i in user.Influencees:
                markup = markup + "<span size='18000'>"+i.nick+"</span><span size='18000' font_weight='bold' foreground='#e44905'> : "+str(round(i.score,0))+"</span>\n\n"
            if markup ==  "":
                markup =  "<span size='18000'>"+user.TwitterID+" doesn't influence anyone, yet.</span>"
            self.influencees.set_markup(markup)
            self.influenceelabel.set_text(user.TwitterID+" influences these people")
            markup = ""
            for t in user.Topics:
                print t.displayName
                markup = markup + "<span size='18000'>"+t.displayName+"</span>\n\n"
            if markup ==  "":
                markup =  "<span size='18000'>"+user.TwitterID+" isn't influencial in any topics, yet.</span>"
            self.topics.set_markup(markup)
            self.topicslabel.set_text(user.TwitterID+" is influencial in these topics")
            if user.HasDelta:
                self.deltas.set_visible(True)
                self.daydelta.set_markup("<span foreground='blue' font_weight='bold' size='22222'>"+str(user.DayDelta)+"</span>")
                self.weekdelta.set_markup("<span foreground='blue' font_weight='bold' size='22222'>"+str(user.WeekDelta)+"</span>")
                self.monthdelta.set_markup("<span foreground='blue' font_weight='bold' size='22222'>"+str(user.MonthDelta)+"</span>")
            else:
                self.deltas.set_visible(False)
        else:
            self.resetScreen(user.ErrorMessage)




